@@ -1,7 +1,7 @@
 // pinentry.rs
 
 // *************************************************************************
-// * Copyright (C) 2017 Daniel Mueller (deso@posteo.net)                   *
+// * Copyright (C) 2017-2018 Daniel Mueller (deso@posteo.net)              *
 // *                                                                       *
 // * This program is free software: you can redistribute it and/or modify  *
 // * it under the terms of the GNU General Public License as published by  *
@@ -17,11 +17,47 @@
 // * along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 // *************************************************************************
 
-use error::Error;
 use std::process;
 
+use crate::error::Error;
 
-const CACHE_ID: &'static str = "nitrokey";
+
+/// PIN type requested from pinentry.
+///
+/// The available PIN types correspond to the PIN types used by the Nitrokey devices:  user and
+/// admin.
+#[derive(Clone, Copy, Debug, PartialEq)]
+pub enum PinType {
+  /// The admin PIN.
+  #[allow(unused)]
+  Admin,
+  /// The user PIN.
+  User,
+}
+
+
+impl PinType {
+  fn cache_id(self) -> &'static str {
+    match self {
+      PinType::Admin => "nitrocli:admin",
+      PinType::User => "nitrocli:user",
+    }
+  }
+
+  fn prompt(self) -> &'static str {
+    match self {
+      PinType::Admin => "Admin PIN",
+      PinType::User => "User PIN",
+    }
+  }
+
+  fn description(self) -> &'static str {
+    match self {
+      PinType::Admin => "Please enter admin PIN",
+      PinType::User => "Please enter user PIN",
+    }
+  }
+}
 
 
 fn parse_pinentry_passphrase(response: Vec<u8>) -> Result<Vec<u8>, Error> {
@@ -45,16 +81,21 @@ fn parse_pinentry_passphrase(response: Vec<u8>) -> Result<Vec<u8>, Error> {
     let (_, error) = lines[0].split_at(4);
     return Err(Error::Error(error.to_string()));
   }
-  return Err(Error::Error("Unexpected response: ".to_string() + &string));
+  Err(Error::Error("Unexpected response: ".to_string() + &string))
 }
 
 
-pub fn inquire_passphrase() -> Result<Vec<u8>, Error> {
-  const PINENTRY_DESCR: &'static str = "+";
-  const PINENTRY_TITLE: &'static str = "Please+enter+user+PIN";
-  const PINENTRY_PASSWD: &'static str = "PIN";
+/// Inquire a PIN of the given type from the user.
+///
+/// This function inquires a PIN of the given type from the user or returns the cached passphrase,
+/// if available.  If an error message is set, it is displayed in the passphrase dialog.
+pub fn inquire_passphrase(pin_type: PinType, error_msg: Option<&str>) -> Result<Vec<u8>, Error> {
+  let cache_id = pin_type.cache_id();
+  let error_msg = error_msg.map(|msg| msg.replace(" ", "+")).unwrap_or(String::from("+"));
+  let prompt = pin_type.prompt();
+  let description = pin_type.description().replace(" ", "+");
 
-  let args = vec![CACHE_ID, PINENTRY_DESCR, PINENTRY_PASSWD, PINENTRY_TITLE].join(" ");
+  let args = vec![cache_id, &error_msg, prompt, &description].join(" ");
   let command = "GET_PASSPHRASE --data ".to_string() + &args;
   // We could also use the --data parameter here to have a more direct
   // representation of the passphrase but the resulting response was
@@ -65,7 +106,7 @@ pub fn inquire_passphrase() -> Result<Vec<u8>, Error> {
   let output = process::Command::new("gpg-connect-agent").arg(command)
     .arg("/bye")
     .output()?;
-  return parse_pinentry_passphrase(output.stdout);
+  parse_pinentry_passphrase(output.stdout)
 }
 
 
@@ -77,18 +118,18 @@ fn parse_pinentry_response(response: Vec<u8>) -> Result<(), Error> {
     // We got the only valid answer we accept.
     return Ok(());
   }
-  return Err(Error::Error("Unexpected response: ".to_string() + &string));
+  Err(Error::Error("Unexpected response: ".to_string() + &string))
 }
 
 
-/// Clear the cached passphrase.
-pub fn clear_passphrase() -> Result<(), Error> {
-  let command = "CLEAR_PASSPHRASE ".to_string() + CACHE_ID;
+/// Clear the cached passphrase of the given type.
+pub fn clear_passphrase(pin_type: PinType) -> Result<(), Error> {
+  let command = "CLEAR_PASSPHRASE ".to_string() + pin_type.cache_id();
   let output = process::Command::new("gpg-connect-agent").arg(command)
     .arg("/bye")
     .output()?;
 
-  return parse_pinentry_response(output.stdout);
+  parse_pinentry_response(output.stdout)
 }
 
 
